==> flutter_mylibrary-0.3.69.tar.gz: lib/http/exception/http_error.dart <==
import 'package:dio/dio.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/utils/utils.dart';


/// @desc  网络请求全局通知
/// @time 2019/3/20 10:02 AM
/// @author Cheney
class HttpError implements Exception {
  ///HTTP 状态码
  static const int UNAUTHORIZED = 401;
  static const int FORBIDDEN = 403;
  static const int NOT_FOUND = 404;
  static const int REQUEST_TIMEOUT = 408;
  static const int INTERNAL_SERVER_ERROR = 500;
  static const int BAD_GATEWAY = 502;
  static const int SERVICE_UNAVAILABLE = 503;
  static const int GATEWAY_TIMEOUT = 504;

  ///未知错误
  static const String UNKNOWN = "UNKNOWN";

  ///解析错误
  static const String PARSE_ERROR = "PARSE_ERROR";

  ///网络错误
  static const String NETWORK_ERROR = "NETWORK_ERROR";

  ///协议错误
  static const String HTTP_ERROR = "HTTP_ERROR";

  ///证书错误
  static const String SSL_ERROR = "SSL_ERROR";

  ///连接超时
  static const String CONNECT_TIMEOUT = "CONNECT_TIMEOUT";

  ///响应超时
  static const String RECEIVE_TIMEOUT = "RECEIVE_TIMEOUT";

  ///发送超时
  static const String SEND_TIMEOUT = "SEND_TIMEOUT";

  ///网络请求取消
  static const String CANCEL = "CANCEL";

  String code;

  String message;

  String url;

  DioError dioError;

  HttpError(this.code, this.message, {this.url});


  HttpError.dioError(DioError error, s) {
    this.dioError = error;
    message = error.message;
    switch (error.type) {
      case DioErrorType.CONNECT_TIMEOUT:
        code = CONNECT_TIMEOUT;
        message = CONNECT_TIMEOUT_MSG;
        break;
      case DioErrorType.RECEIVE_TIMEOUT:
        code = RECEIVE_TIMEOUT;
        message = RECEIVE_TIMEOUT_MSG;
        break;
      case DioErrorType.SEND_TIMEOUT:
        code = SEND_TIMEOUT;
        message = SEND_TIMEOUT_MSG;
        break;
      case DioErrorType.RESPONSE:
        code = HTTP_ERROR;
        message = HTTP_ERROR_MSG;
        try {
          int errCode = error.response.statusCode;
          switch (errCode) {
            case 400:
              message = '400请求语法错误';
              break;
            case 401:
              message = '401没有权限';
              break;
            case 403:
              message = '403服务器拒绝执行';
              break;
            case 404:
              message = '404无法连接服务器';
              break;
            case 405:
              message = '405请求方法被禁止';
              break;
            case 500:
              message = '500服务器内部错误';
              break;
            case 502:
              message = '502无效的请求';
              break;
            case 503:
              message = '503服务器挂了';
              break;
            case 505:
              message = '505不支持HTTP协议请求';
              break;
            default:
              message = error.response.statusMessage;
          }
        } on Exception catch (_) {
          message = '未知错误';
        }
        break;
      case DioErrorType.CANCEL:
        code = CANCEL;
        message = CANCEL_MSG;
        break;
      case DioErrorType.DEFAULT:
        code = UNKNOWN;
        message = error.message??s.toString();
        break;
    }
  }

  @override
  String toString() {
    return 'HttpError{code: $code, message: $message}';
  }

}

==> flutter_mylibrary-0.4.15.tar.gz: lib/http/exception/http_error.dart <==
import 'package:dio/dio.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/utils/utils.dart';


/// @desc  网络请求全局通知
/// @time 2019/3/20 10:02 AM
/// @author Cheney
class HttpError implements Exception {
  ///HTTP 状态码
  static const int UNAUTHORIZED = 401;
  static const int FORBIDDEN = 403;
  static const int NOT_FOUND = 404;
  static const int REQUEST_TIMEOUT = 408;
  static const int INTERNAL_SERVER_ERROR = 500;
  static const int BAD_GATEWAY = 502;
  static const int SERVICE_UNAVAILABLE = 503;
  static const int GATEWAY_TIMEOUT = 504;

  ///未知错误
  static const String UNKNOWN = "UNKNOWN";

  ///解析错误
  static const String PARSE_ERROR = "PARSE_ERROR";

  ///网络错误
  static const String NETWORK_ERROR = "NETWORK_ERROR";

  ///协议错误
  static const String HTTP_ERROR = "HTTP_ERROR";

  ///证书错误
  static const String SSL_ERROR = "SSL_ERROR";

  ///连接超时
  static const String CONNECT_TIMEOUT = "CONNECT_TIMEOUT";

  ///响应超时
  static const String RECEIVE_TIMEOUT = "RECEIVE_TIMEOUT";

  ///发送超时
  static const String SEND_TIMEOUT = "SEND_TIMEOUT";

  ///网络请求取消
  static const String CANCEL = "CANCEL";

  ///网络请求错误
  static const String CODE_INCORRECT = "CODE_INCORRECT";


  String code;

  String message;

  String url;

  DioError dioError;

  HttpError(this.code, this.message, {this.url});


  HttpError.dioError(DioError error) {
    this.dioError = error;
    message = error.message;
    switch (error.type) {
      case DioErrorType.CONNECT_TIMEOUT:
        code = CONNECT_TIMEOUT;
        message = CONNECT_TIMEOUT_MSG;
        break;
      case DioErrorType.RECEIVE_TIMEOUT:
        code = RECEIVE_TIMEOUT;
        message = RECEIVE_TIMEOUT_MSG;
        break;
      case DioErrorType.SEND_TIMEOUT:
        code = SEND_TIMEOUT;
        message = SEND_TIMEOUT_MSG;
        break;
      case DioErrorType.RESPONSE:
        code = HTTP_ERROR;
        message = HTTP_ERROR_MSG;
        try {
          int errCode = error.response.statusCode;
          switch (errCode) {
            case 400:
              message = '400请求语法错误';
              break;
            case 401:
              message = '401没有权限';
              break;
            case 403:
              message = '403服务器拒绝执行';
              break;
            case 404:
              message = '404无法连接服务器';
              break;
            case 405:
              message = '405请求方法被禁止';
              break;
            case 500:
              message = '500服务器内部错误';
              break;
            case 502:
              message = '502无效的请求';
              break;
            case 503:
              message = '503服务器挂了';
              break;
            case 505:
              message = '505不支持HTTP协议请求';
              break;
            default:
              message = error.response.statusMessage;
          }
        } on Exception catch (_) {
          message = '未知错误';
        }
        break;
      case DioErrorType.CANCEL:
        code = CANCEL;
        message = CANCEL_MSG;
        break;
      case DioErrorType.DEFAULT:
        code = UNKNOWN;
        message = error.message;
        break;
    }
  }

  @override
  String toString() {
    return 'HttpError{code: $code, message: $message}';
  }

}
